"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function create(info) {
    // Get a list of things to remove from the completion list from the config object.
    // If nothing was specified, we'll just remove 'caller'
    const whatToRemove = info.config.remove || ['caller'];
    const log = msg => info.project.projectService.logger.info(`[ts-transform-css-modules] ${msg}`);
    // Diagnostic logging
    // Set up decorator
    const proxy = Object.create(null);
    const oldLS = info.languageService;
    for (const k in oldLS) {
        proxy[k] = function () {
            return oldLS[k].apply(oldLS, arguments);
        };
    }
    // Remove specified entries from completion list
    proxy.getCompletionsAtPosition = (fileName, position) => {
        const prior = info.languageService.getCompletionsAtPosition(fileName, position);
        const oldLength = prior.entries.length;
        prior.entries = prior.entries.filter(e => whatToRemove.indexOf(e.name) < 0);
        // Sample logging for diagnostic purposes
        if (oldLength !== prior.entries.length) {
            log(`Removed ${oldLength - prior.entries.length} entries from the completion list`);
        }
        return prior;
    };
    return proxy;
}
exports.default = () => ({ create });
